"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.minifyHtml = exports.injectHtml = void 0;
const ejs_1 = require("ejs");
const html_minifier_terser_1 = require("html-minifier-terser");
function injectHtml(options = {}) {
    return {
        name: 'vite:injectHtml',
        transformIndexHtml: {
            enforce: 'pre',
            transform(html) {
                const { injectData = {}, injectOptions = {}, tags = [] } = options;
                return {
                    html: ejs_1.render(html, injectData, injectOptions),
                    tags: tags,
                };
            },
        },
    };
}
exports.injectHtml = injectHtml;
function minifyHtml(minifyOptions = true) {
    return {
        name: 'vite:minifyHtml',
        transformIndexHtml(html) {
            if (!minifyOptions) {
                return html;
            }
            // https://github.com/terser/html-minifier-terser#options-quick-reference
            const defaultMinifyOptions = {
                collapseBooleanAttributes: true,
                collapseWhitespace: true,
                minifyCSS: true,
                minifyJS: true,
                minifyURLs: true,
                removeAttributeQuotes: true,
                removeComments: true,
                removeEmptyAttributes: true,
                ...(typeof minifyOptions === 'boolean' ? {} : minifyOptions),
            };
            return html_minifier_terser_1.minify(html, defaultMinifyOptions);
        },
    };
}
exports.minifyHtml = minifyHtml;
function default_1(options = {}) {
    const { inject = {}, minify = {} } = options;
    return [injectHtml(inject), minifyHtml(minify)];
}
exports.default = default_1;
